# Analisis de cointegracion, 2016
#Profesor: Miguel Angel Mendoza, FE-UNAM 
#Modelos de cointegracion

#Cargar la libreria urca
library(urca)
library(car)

#Cambiar el directorio de trabajo
setwd("/Volumes/LACIE SHARE/Academico/LibroEconometria_R/Capitulo_9/BaseDatos_Capitulo9")

# Lectura de la base de datos
load("Consumo.RData")
summary(Consumo)

# Se asigna la variable de serie de tiempo al objeto PIB_MEX y  aplican primera diferencia
lpib_mex <- log(Consumo$pib_mex)
lcp_mex <- log(Consumo$cp_mex)
dlpib_mex <- diff(lpib_mex)
dlcp_mex <- diff(lcp_mex)


# Se asigna la variable que ordena en el tiempo 
periodo <- Consumo$Periodo
summary(periodo)

# Para graficar la variable del logaritmo del PIB_Mex  y el Consumo_Mex en el tiempo
plot(periodo, lpib_mex, main="Consumo y PIB de Mexico",ylim=c(15, 17))
lines(lpib_mex, col="black")
lines(lcp_mex, col="red")

# Para construir un grafica con las primera diferencia del Consumo yPIB
plot(dlpib_mex, main="Diferencias en logaritmo del consumo 
     y del PIB de Mexico")
lines(dlpib_mex, col="black")
lines(dlcp_mex, col="red")

# Funcion consumo para probar cointegracion tipo Granger
mod_1 <- lm(lcp_mex ~ lpib_mex)
summary(mod_1)

# Generar los residuales de la ecuacion
res_1 <- residuals.lm(mod_1)
summary(res_1)

# Grafica de los errores
residualPlot(mod_1)


# Prueba de ADF para cointegracion tipo Granger
lc.df <- ur.df(y=res_1, type='trend',lags=4, selectlags=c("AIC"))
summary(lc.df)

lc.df <- ur.df(y=res_1, type='drift',lags=4, selectlags=c("AIC"))
summary(lc.df)

lc.df <- ur.df(y=res_1, type='none',lags=4, selectlags=c("AIC"))
summary(lc.df)

#Pruebas PP para cointegracion tipo Granger
lc.pp <- ur.pp(res_1, type="Z-tau",model="trend", lags="long")
summary(lc.pp)

lc.pp <- ur.pp(res_1, type="Z-tau",model="constant", lags="long")
summary(lc.pp)

#Pruebas KPSS para cointegracion tipo Granger
lc.kpss <- ur.kpss(res_1, type="tau", lags="short", use.lag = NULL)
summary(lc.kpss)

# Prueba de Phillips y Ouliaris para cointegracion 
ecb.consumo <- cbind(lcp_mex, lpib_mex)
Lc.po <- ca.po(ecb.consumo, type="Pz")
summary(Lc.po)
Lc.po <- ca.po(ecb.consumo, type="Pu")
summary(Lc.po)

# Modelo de correccion de Error: Metodolog??a de Granger
mod_1 <- lm(lcp_mex ~ lpib_mex)
summary(mod_1)
res_1 <- residuals.lm(mod_1)
summary(res_1)
res_1.l <- lag(res_1)

mod_ce_1 <- lm(dlcp_mex ~ dlpib_mex+res_1.l)
summary(mod_ce_1)

# Para aplicar el procedimiento de Johansen, primero se combinan las variables
#en un solo objeto

ecb.consumo <- cbind(lcp_mex,lpib_mex)

# Prueba  Johasen de cointegracion de la traza 
summary(ca.jo(ecb.consumo, type="trace",ecdet="none",spec=c("longrun"), K=4))
summary(ca.jo(ecb.consumo, type="trace",ecdet="const",spec=c("longrun"), K=4))
summary(ca.jo(ecb.consumo, type="trace",ecdet="trend",spec=c("longrun"), K=4))

# Prueba  Johasen de cointegracion de la raiz maxima 
summary(ca.jo(ecb.consumo, type="eigen",ecdet="none", K=4))
summary(ca.jo(ecb.consumo, type="eigen",ecdet="const", K=4))
summary(ca.jo(ecb.consumo, type="eigen",ecdet="trend", K=4))


# Modelo de correccion de Error: Metodologia de Johansen y Joselius
summary(ca.jo(ecb.consumo, type="trace",ecdet="none",spec=c("longrun"), K=4))

# Con vector normalizado del vector de cointegarcion de J-J
res_2 <- lcp_mex-1.280708*lpib_mex
summary(res_2)
res_2.l <- lag(res_2)
summary(res_2.l)


mod_ce_2 <- lm(dlcp_mex ~ dlpib_mex+res_2.l)
summary(mod_ce_2)
